Learn R Programming

DOPE (version 2.1.0)

dea_factsheets: Drug ontology information from https://www.dea.gov/factsheets

Description

A dataset containing a record for each drug category listed on https://www.dea.gov/factsheets, the class in which that drug belongs in and path to the factsheet.

Usage

data(dea_factsheets)

Arguments

Format

A tibble with 29 rows and 3 variables:

class

the drug class

category

the drug category

fact_path

the unique path to the drug's factsheet