Learn R Programming

DOPE (version 2.1.0)

drug_stop_words: A vector with drug-specific stop words in English

Description

These are extraneous words or characters found in several clinical data that have been accumulated to form a vector that can be used to parse out drug names from corpus of text.

Usage

data(drug_stop_words)

Arguments

Format

A vector with 47 words: