powered by
This function provides a table with drug class and category information all of the known drugs.
lookup( drug_vec = NULL, ..., searchClass = TRUE, searchCategory = TRUE, searchSynonym = TRUE )
a vector of strings holding possible drug names
multiple strings holding possible drug names
Should the substances listed in ... be searched for in column class? Defaults to TRUE.
...
class
Should the substances listed in ... be searched for in column category? Defaults to TRUE.
category
Should the substances listed in ... be searched for in column synonym? Defaults to TRUE.
synonym
A lookup table with category data.frame having four columns: original search term, drug class, drug category, and drug street name.
data.frame
# NOT RUN { lookup("zip", "shrooms") # }
Run the code above in your browser using DataLab