Learn R Programming

DOPE (version 2.1.0)

lookup_df: A lookup table with drug class, category, and synonyms

Description

A dataset containing a record for each drug synonym

Usage

data(lookup_df)

Arguments

Format

A tibble with 4,296 rows and 3 variables:

class

the drug class

category

the drug category

synonym

drug synonym