Learn R Programming

DOPE (version 2.1.0)

lookup_syn: Make a table with the class and category for a drug name

Description

This function provides a table with drug synonyms that have the same class and category as the search term.

Usage

lookup_syn(drug_name)

Arguments

drug_name

a string of a single drug name.

Value

A lookup table with category data.frame having three columns: drug class, drug category match, and synonym name.

Examples

Run this code
# NOT RUN {
  lookup_syn("zip")
# }

Run the code above in your browser using DataLab