Learn R Programming

DOPE (version 2.1.0)

noslang_raw: Drug terms from https://www.noslang.com/drugs/dictionary

Description

A dataset containing a record for a drug rleated term and it's description. This contains both drug names and other things like drug amounts.

Usage

data(noslang_raw)

Arguments

Format

A tibble with 3172 rows and 2 variables:

street_name

Slang term

description

Text description of drug term