Learn R Programming

DOPE (version 2.1.0)

parse: Parse a vector of free text containing drug information

Description

This function provides a dataframe of parsed out strings from a free text field, input as a vector, specified by the user.

Usage

parse(drug_vec)

Arguments

drug_vec

A vector containing the free text to be parsed

Value

A n x 1 vector of class character.

Examples

Run this code
# NOT RUN {
  parse("Lortab and Percocet")

# }

Run the code above in your browser using DataLab