powered by
This function provides a table with drug synonyms that have the same class and category as the search term.
lookup_syn(drug_name)
a string of a single drug name.
A lookup table with category data.frame having three columns: drug class, drug category match, and synonym name.
data.frame
# NOT RUN { lookup_syn("zip") # }
Run the code above in your browser using DataLab