powered by
This function provides a dataframe of parsed out strings from a free text field, input as a vector, specified by the user.
parse(drug_vec)
A vector containing the free text to be parsed
A n x 1 vector of class character.
character
# NOT RUN { parse("Lortab and Percocet") # }
Run the code above in your browser using DataLab